# megastep

**This repo is still pre-release. It's public because it makes some bits of testing & distribution setup easier. If you come across it before this warning is removed, don't expect things to work**.

**megastep** helps you build 1-million FPS reinforcement learning environments with a single consumer GPU.

## [Homepage](https://andyljones.com/megastep)
